..  Copyright 2019 Christoph Wagner
        https://www.tu-ilmenau.de/it-ems/

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

.. toctree::
   :glob:
   :maxdepth: 2
   :hidden:

.. automodule:: chefkoch

Chefkoch under development
--------------------

Please tune in soon for more details

Contributions
-------------

There are many ways you as an individual can contribute. We are happy about feature requests, bug reports and of course contributions in form of additional features. To these ends, please step by at `Github <https://github.com/EMS-TU-Ilmenau/chefkoch>`_ where we organize the work on the package.


Affiliations and Credits
------------------------

Currently the project is maintained by Christoph Wagner at the `EMS group <https://www.tu-ilmenau.de/it-ems/>`_ at `TU Ilmenau  <https://www.tu-ilmenau.de/>`_.
